@@ -16,23 +16,18 @@
 
 import collections
 import copy
+import io
 import os
 import sys
 import traceback
 
-from oslo_utils import encodeutils
 from oslo_utils import reflection
-import six
 
 from taskflow import exceptions as exc
 from taskflow.utils import iter_utils
-from taskflow.utils import mixins
 from taskflow.utils import schema_utils as su
 
 
-_exception_message = encodeutils.exception_to_unicode
-
-
 def _copy_exc_info(exc_info):
     if exc_info is None:
         return None
@@ -58,7 +53,7 @@ def _are_equal_exc_info_tuples(ei1, ei2):
     # because we want the types to be exactly the same, not just have
     # one be inherited from the other.
     if not all((type(ei1[1]) == type(ei2[1]),  # noqa: E721
-                _exception_message(ei1[1]) == _exception_message(ei2[1]),
+                str(ei1[1]) == str(ei2[1]),
                 repr(ei1[1]) == repr(ei2[1]))):
         return False
     if ei1[2] == ei2[2]:
@@ -68,7 +63,7 @@ def _are_equal_exc_info_tuples(ei1, ei2):
     return tb1 == tb2
 
 
-class Failure(mixins.StrMixin):
+class Failure():
     """An immutable object that represents failure.
 
     Failure objects encapsulate exception information so that they can be
@@ -120,7 +115,7 @@ class Failure(mixins.StrMixin):
       to have code ran when this happens, and this can cause issues and
       side-effects that the receiver would not have intended to have caused).
 
-    TODO(harlowja): use parts of http://bugs.python.org/issue17911 and the
+    TODO(harlowja): use parts of :pybug:`17911` and the
     backport at https://pypi.org/project/traceback2/ to (hopefully)
     simplify the methods and contents of this object...
     """
@@ -196,7 +191,7 @@ class Failure(mixins.StrMixin):
             if not self._exc_type_names:
                 raise TypeError("Invalid exception type '%s' (%s)"
                                 % (exc_info[0], type(exc_info[0])))
-            self._exception_str = _exception_message(self._exc_info[1])
+            self._exception_str = str(self._exc_info[1])
             self._traceback_str = ''.join(
                 traceback.format_tb(self._exc_info[2]))
             self._causes = kwargs.pop('causes', None)
@@ -210,7 +205,7 @@ class Failure(mixins.StrMixin):
             if kwargs:
                 raise TypeError(
                     'Failure.__init__ got unexpected keyword argument(s): %s'
-                    % ', '.join(six.iterkeys(kwargs)))
+                    % ', '.join(kwargs.keys()))
 
     @classmethod
     def from_exception(cls, exception):
@@ -343,7 +338,12 @@ class Failure(mixins.StrMixin):
     def reraise(self):
         """Re-raise captured exception."""
         if self._exc_info:
-            six.reraise(*self._exc_info)
+            tp, value, tb = self._exc_info
+            if value is None:
+                value = tp()
+            if value.__traceback__ is not tb:
+                raise value.with_traceback(tb)
+            raise value
         else:
             raise exc.WrappedFailure([self])
 
@@ -424,12 +424,12 @@ class Failure(mixins.StrMixin):
             self._causes = tuple(self._extract_causes_iter(self.exception))
             return self._causes
 
-    def __unicode__(self):
+    def __str__(self):
         return self.pformat()
 
     def pformat(self, traceback=False):
         """Pretty formats the failure object into a string."""
-        buf = six.StringIO()
+        buf = io.StringIO()
         if not self._exc_type_names:
             buf.write('Failure: %s' % (self._exception_str))
         else:
